@@ -1,6 +1,6 @@
 package Data::Dump::SortKeys;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use strict;
 use vars qw(@EXPORT @EXPORT_OK $DEBUG);
@@ -14,13 +14,15 @@ require Exporter;
 $DEBUG = 0;
 
 use overload ();
-use vars qw(%seen %refcnt @dump @fixup %require $TRY_BASE64 @FILTERS $INDENT $SORT_KEYS);
+use vars qw(%seen %refcnt @dump @fixup %require $TRY_BASE64 @FILTERS $INDENT $SORT_KEYS $REMOVE_PRAGMAS);
 
 $TRY_BASE64 = 50 unless defined $TRY_BASE64;
 $INDENT = "  " unless defined $INDENT;
 
 $SORT_KEYS = undef;
 
+$REMOVE_PRAGMAS = 0;
+
 sub dump
 {
     local %seen;
@@ -373,7 +375,7 @@ sub _dump
 	$out .= "}";
     }
     elsif ($type eq "CODE") {
-	$out = 'sub { ... }';
+	$out = code($rval);
     }
     elsif ($type eq "VSTRING") {
         $out = sprintf +($ref ? '\v%vd' : 'v%vd'), $$rval;
@@ -484,6 +486,41 @@ sub format_list
     }
 }
 
+my $deparse;
+sub code {
+    my $code = shift;
+    unless ($deparse) {
+        require B::Deparse;
+        $deparse = B::Deparse->new("-l"); # -i option doesn't have any effect?
+    }
+
+    my $res = $deparse->coderef2text($code);
+
+    my ($res_before_first_line, $res_after_first_line) =
+        $res =~ /(.+?)^(#line .+)/ms;
+
+    if ($REMOVE_PRAGMAS) {
+        $res_before_first_line = "{\n";
+    #} elsif ($PERL_VERSION < 5.016) {
+    #    # older perls' feature.pm doesn't yet support q{no feature ':all';}
+    #    # so we replace it with q{no feature}.
+    #    $res_before_first_line =~ s/no feature ':all';/no feature;/m;
+    }
+    $res_after_first_line =~ s/^#line .+\n//gm;
+
+    $res = "sub " . $res_before_first_line . $res_after_first_line;
+
+    if (length($res) <= 60) {
+        $res =~ s/^ +//gm;
+        $res =~ s/\n+/ /g;
+        $res =~ s/;\s+\}\z/ }/;
+    } else {
+        $res =~ s/^ +/$INDENT/gm;
+    }
+
+    $res;
+}
+
 sub str {
   if (length($_[0]) > 20) {
       for ($_[0]) {
@@ -573,7 +610,7 @@ Data::Dump::SortKeys - Data::Dump but lets you custom sort hash keys
 
 =head1 VERSION
 
-This document describes version 0.03 of Data::Dump::SortKeys (from Perl distribution Data-Dump-SortKeys), released on 2015-12-23.
+This document describes version 0.04 of Data::Dump::SortKeys (from Perl distribution Data-Dump-SortKeys), released on 2015-12-28.
 
 =head1 SYNOPSIS
 
@@ -597,7 +634,8 @@ This document describes version 0.03 of Data::Dump::SortKeys (from Perl distribu
 
 =head1 DESCRIPTION
 
-B<An experimental fork of Data::Dump 1.23 which lets you custom sort hash keys.>
+B<An experimental fork of Data::Dump 1.23 which lets you custom sort hash keys
+and dump coderefs.>
 
 This module provide a few functions that traverse their
 argument and produces a string as its result.  The string contains
@@ -710,6 +748,20 @@ for the dump output.  The default is 50.  Set it to 0 to disable base64 dumps.
 A custom hook which is called with ($hashref) when dumping a hash, to get the
 sorted hash keys. It should return a list containing the sorted keys.
 
+=item $Data::Dump::SortKeys::REMOVE_PRAGMAS
+
+If set to 1, then pragmas at the start of coderef dump will be removed. Coderef
+dump is produced by L<B::Deparse> and is of the form like:
+
+ sub { use feature 'current_sub', 'evalbytes', 'fc', 'say', 'state', 'switch', 'unicode_strings', 'unicode_eval'; $a <=> $b }
+
+If you want to dump short coderefs, the pragmas might be distracting. You can
+turn turn on this option which will make the above dump become:
+
+ sub { $a <=> $b }
+
+Note that without the pragmas, the dump might be incorrect.
+
 =back
 
 =head1 LIMITATIONS
